//
// reftestx.cc
//
// Copyright (C) 1996 Limit Point Systems, Inc.
//
// Author: Curtis Janssen <cljanss@limitpt.com>
// Maintainer: LPS
//
// This file is part of the SC Toolkit.
//
// The SC Toolkit is free software; you can redistribute it and/or modify
// it under the terms of the GNU Library General Public License as published by
// the Free Software Foundation; either version 2, or (at your option)
// any later version.
//
// The SC Toolkit is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Library General Public License for more details.
//
// You should have received a copy of the GNU Library General Public License
// along with the SC Toolkit; see the file COPYING.LIB.  If not, write to
// the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
//
// The U.S. Government is granted a limited license as per AL 91-7.
//

#ifdef __GNUG__
#pragma implementation "reftmpl.h"
#pragma implementation "reftestx.h"
#endif

#include <util/ref/reftestx.h>

using sc::X;
using sc::Y;
using sc::Ref;

#ifdef __GNUG__
typedef Ref<X> forced_implementation_of_RefX;
#endif

int X::nx = 0;

X::X(): x(0) { nx++; }
X::~X() { nx--; }

Y::Y(): y(1) {}
Y::~Y() {}
